| array-indexing | R Documentation |
These operators can be used to extract or replace data from an array by indices. Normal R array selection rules apply. The only limitation is that the indices have to be consecutive.
## S3 method for class 'zarr_array'
x[..., drop = TRUE]
x |
A |
... |
Indices specifying elements to extract or replace. Indices are
numeric, empty (missing) or |
drop |
If |
When extracting data, a vector, matrix or array, having dimensions as
specified in the indices. When replacing part of the Zarr array, returns
x invisibly.
x <- array(1:100, c(10, 10))
z <- as_zarr(x)
arr <- z[["/"]]
arr[3:5, 7:9]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.