| as_zarr | R Documentation |
This function creates a Zarr object from an R vector, matrix or array. Default settings will be taken from the R object (data type, shape). Data is chunked into chunks of length 100 (or less if the array is smaller) and compressed.
as_zarr(x, name = NULL, location = NULL)
x |
The R object to convert. Must be a vector, matrix or array of a numeric or logical type. |
name |
Optional. The name of the Zarr array to be created. |
location |
Optional. If supplied, either an existing zarr_group in a
Zarr object, or a character string giving the location on a local file
system where to persist the data. If the argument is a |
If the location argument is a zarr_group, the new Zarr array is
returned. Otherwise, the Zarr object that is newly created and which
contains the Zarr array, or an error if the Zarr object could not be
created.
x <- array(1:400, c(5, 20, 4))
z <- as_zarr(x)
z
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.