sub-sub-.zarr: Get a group or array from a Zarr object

[[.zarrR Documentation

Get a group or array from a Zarr object

Description

This method can be used to retrieve a group or array from the Zarr object by its path.

Usage

## S3 method for class 'zarr'
x[[i]]

Arguments

x

A zarr object to extract a group or array from.

i

The path to a group or array in x.

Value

An instance of zarr_group or zarr_array, or NULL if the path is not found.

Examples

z <- create_zarr()
z[["/"]]

zarr documentation built on Feb. 11, 2026, 5:07 p.m.