| [[.zarr_group | R Documentation |
This method can be used to retrieve a group or array from the Zarr group by a relative path to the desired group or array.
## S3 method for class 'zarr_group'
x[[i]]
x |
A |
i |
The path to a group or array in |
An instance of zarr_group or zarr_array, or NULL if the path is
not found.
z <- create_zarr()
z$add_group("/", "tst")
z$add_group("/tst", "subtst")
tst <- z[["/tst"]]
tst[["subtst"]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.