zarr-package: zarr: Native and Extensible R Driver for 'Zarr'

zarr-packageR Documentation

zarr: Native and Extensible R Driver for 'Zarr'

Description

The 'Zarr' specification is widely used to build libraries for the storage and retrieval of n-dimensional array data from data stores ranging from local file systems to the cloud. This package is a native 'Zarr' implementation in R with support for all required features of 'Zarr' version 3. It is designed to be extensible such that new stores, codecs and extensions can be added easily.

Author(s)

Maintainer: Patrick Van Laake patrick@vanlaake.net [copyright holder]

See Also

Useful links:


zarr documentation built on Feb. 11, 2026, 5:07 p.m.