This class implements the regular chunk grid for Zarr arrays. It manages reading from and writing to Zarr stores, using the codecs for data transformation.
Super classes
zarr_extension -> chunking -> chunk_grid_regular
Active bindings
codecsThe list of codecs used by the chunking scheme. These are set by the array when starting to use chunking for file I/O. Upon reading, the list of registered codecs.
Methods
chunk_grid_regular$new()
Initialize a new chunking scheme for an array.
Usage
chunk_grid_regular$new(array_shape, chunk_shape)chunk_grid_regular$metadata_fragment()
Return the metadata fragment that describes this chunking scheme.
chunk_grid_regular$read()
Read data from the Zarr array into an R object. The read can
span multiple chunks. Reads will be parallelised if
future::plan(multisession) is set; by default the reading is
sequential.
chunk_grid_regular$write()
Write data to the array. Writing data always uses a sequential plan.