This class implements the sharded chunk grid for Zarr arrays. It manages reading from Zarr stores, using the codecs for data transformation included in the sharding configuration. Writing is not supported with this codec. Storing a scalar array in a sharded grid is not possible either and totally useless anyway.
Super classes
zarr_extension -> chunking -> chunk_grid_sharded
Active bindings
inner_shape(read-only) The dimensions of each chunk in the shard.
codecs(read-only) The list of codecs used by the sharding scheme.
index_codecs(read-only) The list of codecs used by the sharding scheme for the indexing of the internal chunks.
Methods
chunk_grid_sharded$new()
Initialize a new sharded chunking scheme for an array.
Usage
chunk_grid_sharded$new(
array_shape,
chunk_shape,
inner_shape,
index_loc,
inner_codecs,
index_codecs
)Arguments
array_shapeInteger vector of the array dimensions.
chunk_shapeInteger vector of the dimensions of each outer chunk, i.e. the size of a shard.
inner_shapeInteger vector of the dimensions of each inner chunk, i.e. the size of a single chunk inside a shard.
index_locLocation of the shard index in the shard file, either "start" or "end".
inner_codecs, index_codecsList of
zarr_codecinstances to decode the inner chunks and the index, respectively.
chunk_grid_sharded$print()
Print a short description of this sharded chunking scheme to the console.
chunk_grid_sharded$metadata_fragment()
Return the metadata fragment that describes this chunking scheme.