open_zarr: Open a Zarr store

View source: R/api.R

open_zarrR Documentation

Open a Zarr store

Description

This function opens a Zarr object, connected to a store located on the local file system or on a remote server using the HTTP protocol. The Zarr object can be either v.2 or v.3.

Usage

open_zarr(location, read_only = FALSE)

Arguments

location

Character string that indicates a location on a file system or a HTTP server where the Zarr store is to be found. The character string may contain UTF-8 characters and/or use a file URI format.

read_only

Optional. Logical that indicates if the store is to be opened in read-only mode. Default is FALSE for a local file system store, TRUE otherwise.

Value

A zarr object.

Examples

fn <- system.file("extdata", "africa.zarr", package = "zarr")
africa <- open_zarr(fn)
africa

zarr documentation built on Feb. 11, 2026, 5:07 p.m.