| open_zarr | R Documentation |
This function opens a Zarr object, connected to a store located on the local file system or on a remote server using the HTTP protocol. The Zarr object can be either v.2 or v.3.
open_zarr(location, read_only = FALSE)
location |
Character string that indicates a location on a file system or a HTTP server where the Zarr store is to be found. The character string may contain UTF-8 characters and/or use a file URI format. |
read_only |
Optional. Logical that indicates if the store is to be
opened in read-only mode. Default is |
A zarr object.
fn <- system.file("extdata", "africa.zarr", package = "zarr")
africa <- open_zarr(fn)
africa
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.