This function will determine the optimal chunking sizes of the array dimensions based on weights per dimension.
Arguments
- dim_sizes
Integer array of dimension lengths, corresponding to the
shapeof the array.- weights
Optional, numeric vector with weights per dimension, in the same order as
dim_sizes. If omitted, each dimension will have a weight of 1L, i.e. no preferential chunking on any dimension.- chunk_values
Optional, integer value given the maximum number of array elements per chunk. Default is 4 million, meaning that the chunk size of
float32data is at most 16MB uncompressed.