| [[.zarr | R Documentation |
This method can be used to retrieve a group or array from the Zarr object by its path.
## S3 method for class 'zarr'
x[[i]]
x |
A |
i |
The path to a group or array in |
An instance of zarr_group or zarr_array, or NULL if the path is
not found.
z <- create_zarr()
z[["/"]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.