| zarr_array | R Documentation |
This class implements a Zarr array. A Zarr array is stored in a node in the hierarchy of a Zarr data set. The array contains the data for an object.
zarr::zarr_node -> zarr_array
data_type(read-only) Retrieve the data type of the array.
shape(read-only) Retrieve the shape of the array, an integer vector.
chunking(read-only) The chunking engine for this array.
chunk_separator(read-only) Retrieve the separator to be used for creating store keys for chunks.
codecsThe list of codecs that this array uses for encoding data (and decoding in inverse order).
new()Initialize a new array in a Zarr hierarchy. The array must already exist in the store
zarr_array$new(name, metadata, parent, store)
nameThe name of the array.
metadataList with the metadata of the array.
parentThe parent zarr_group instance of this new array, can be
missing or NULL if the Zarr object should have just this array.
storeThe zarr_store instance to persist data in.
An instance of zarr_array.
print()Print a summary of the array to the console.
zarr_array$print()
hierarchy()Prints the hierarchy of the groups and arrays to the console. Usually called from the Zarr object or its root group to display the full group hierarchy.
zarr_array$hierarchy(idx, total)
idx, totalArguments to control indentation.
read()Read some or all of the array data for the array.
zarr_array$read(selection)
selectionA list as long as the array has dimensions where each element is a range of indices along the dimension to write. If missing, the entire array will be read.
A vector, matrix or array of data.
write()Write data for the array. The data will be chunked, encoded and persisted in the store that the array is using.
zarr_array$write(data, selection)
dataAn R vector, matrix or array with the data to write. The data in the R object has to agree with the data type of the array.
selectionA list as long as the array has dimensions where each
element is a range of indices along the dimension to write. If missing,
the entire data object will be written.
Self, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.