| zarr_codec | R Documentation |
Zarr codecs encode data from the user data to stored data, using one or more transformations, such as compression. Decoding of stored data is the inverse process, whereby the codecs are applied in reverse order.
zarr::zarr_extension -> zarr_codec
mode(read-only) Retrieve the operating mode of the encoding operation of the codec in form of a string "array -> array", "array -> bytes" or "bytes -> bytes".
from(read-only) Character string that indicates the source data type of this codec, either "array" or "bytes".
to(read-only) Character string that indicates the output data type of this codec, either "array" or "bytes".
configuration(read-only) A list with the configuration parameters of the codec, exactly like they are defined in Zarr. This field is read-only but each codec class has fields to set individual parameters.
new()Create a new codec object.
zarr_codec$new(name, configuration)
nameThe name of the codec, a single character string.
configurationA list with the configuration parameters for this codec.
An instance of this class.
copy()Create a new, independent copy of this codec.
zarr_codec$copy()
This method always throws an error.
print()Print a summary of the codec to the console.
zarr_codec$print()
metadata_fragment()Return the metadata fragment that describes this codec.
zarr_codec$metadata_fragment()
A list with the metadata of this codec.
encode()This method encodes a data object but since this is the base codec class the "encoding" is a no-op.
zarr_codec$encode(data)
dataThe data to be encoded.
The encoded data object, unaltered.
decode()This method decodes a data object but since this is the base codec class the "decoding" is a no-op.
zarr_codec$decode(data)
dataThe data to be decoded.
The decoded data object, unaltered.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.