The Zarr sharding codec is not a true codec in the sense that it does not encode or decode - that is left up to regular codec defined inside this "codec" configuration. This implementation can read from a store using sharding, writing is not supported.
Super classes
zarr_extension -> zarr_codec -> zarr_codec_sharding
Methods
zarr_codec_sharding$new()
Create a new "crc32c" codec object.
Usage
zarr_codec_sharding$new(configuration)