This class implements the "ref" convention. This convention provides a standard way of referring to objects from a referring group or array in a Zarr store. The referenced object may be located in the same Zarr store or in an external Zarr store. In particular, the following convention is implemented here:
{
"schema_url": "https://raw.githubusercontent.com/R-CF/zarr_convention_ref/main/schema.json",
"spec_url": "https://raw.githubusercontent.com/R-CF/zarr_convention_ref/main/README.md",
"uuid": "d89b30cf-ed8c-43d5-9a16-b492f0cd8786",
"name": "ref",
"description": "Referencing Zarr objects external to the current Zarr object"
}
Super class
zarr_convention -> zarr_conv_ref
Methods
Inherited methods
zarr_conv_ref$set()
Set the attributes for this convention for use in a Zarr node.
Arguments
nodeCharacter string. Path to the Zarr node containing the data of interest. The path is relative to the referring node when argument
uriis missing, absolute from the root of the Zarr store otherwise.uriOptional, character string. URI of an external Zarr store. Omit for nodes that are in the same local store as the referring node.
attributeOptional, a character string with a JSON pointer to a referenced attribute in the metadata of the referenced
node.
zarr_conv_ref$clear()
Clear any attributes that may have been set. Only the properties of the convention itself will remain in place.