This class implements the "ref" convention. This convention provides a standard way of referring to objects from a referring group or array in a Zarr store. The referenced object may be located in the same Zarr store or in an external Zarr store. In particular, the following convention is implemented here:
{
"schema_url": "https://raw.githubusercontent.com/R-CF/zarr_convention_ref/main/schema.json",
"spec_url": "https://raw.githubusercontent.com/R-CF/zarr_convention_ref/main/README.md",
"uuid": "d89b30cf-ed8c-43d5-9a16-b492f0cd8786",
"name": "ref",
"description": "Referencing Zarr objects external to the current Zarr object"
}
Super class
zarr::zarr_convention -> zarr_conv_ref
Active bindings
uriThe "uri" field, a character string of an external Zarr store. The URI must follow RFC 3986 and preferably points to a locatable resource like a file on a file system or a store on a web site that is accessible to the same process that opened up the Zarr store having this reference.
nodeThe "node" field, a character string giving the path to a group or array in the current Zarr store or in the store pointed at by the "uri" field.
attributeThe "attribute" field, a character string with a JSON pointer to a referenced attribute in the metadata of the referenced
node.
Methods
Inherited methods
Method write()
Write the data of this instance in the attributes of a Zarr object.