This class implements a basic Zarr convention. A convention is a set of attributes specific to a certain domain of application. These attributes are included in Zarr group and array attributes and are interpreted by application code. Conventions may be grouped in domains and combined with other conventions.
Application-specific conventions need to inherit from this base class and redefine relevant methods. Descendant conventions may have additional methods specific to the domain of the data.
It is not useful to directly instantiate this class, use a descendant convention instead. It is recommended that descendant classes use the "zarr_conv_****" naming pattern and that they are included in a R package with similar conventions and/or domain(s).
Active bindings
name(read-only) The name of the convention, possibly with a trailing semi-colon ":".
schema(read-only) The URL to the schema of the convention.
uuid(read-only) The UUID of the convention, in string format.
specThe URL to the specification of the convention.
descriptionA short description of the convention.
Methods
Method new()
Create a new instance of a Zarr convention agent. This is a "virtual" ancestor class that should not be instantiated directly - instead use one of the descendant classes.
Usage
zarr_convention$new(name, schema, uuid)Method register()
Register the use of a convention in the attributes of a Zarr object.
Method write()
Write the data of a convention instance in the attributes of a Zarr object. This method does not do any actual writing. Descendant classes should implement their specific solutions.